DELIMITER //

CREATE TABLE IF NOT EXISTS `recovery_tokens` (
  `ID` int(11) NOT NULL AUTO_INCREMENT,
  `AccountID` int(11) NOT NULL,
  `Date` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `Token` varchar(100) NOT NULL,
  `isUsed`  tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ID`),
  KEY `AccountID` (`AccountID`),
  UNIQUE KEY `Token` (`Token`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8//


ALTER TABLE `recovery_tokens`
  ADD CONSTRAINT `recovery_tokens_ibfk_1` FOREIGN KEY (`AccountID`) REFERENCES `accounts` (`ID`)//


  DROP FUNCTION IF EXISTS CreateRecoveryToken//
CREATE FUNCTION `CreateRecoveryToken`	( 	`AccountID` INT,
											`Token` VARCHAR(100) charset utf8
										)	RETURNS int(11)
    NO SQL
BEGIN
	DECLARE checker INT;

	SET checker = -1;
	SELECT recovery_tokens.ID
	INTO checker
	FROM `recovery_tokens`
	WHERE recovery_tokens.Token = Token
	LIMIT 1;
	IF checker <= 0 THEN
		RETURN -1;
	END IF; 

	INSERT INTO `recovery_tokens`
			(recovery_tokens.AccountID, recovery_tokens.Token )
	VALUES	(AccountID, Token);
	RETURN LAST_INSERT_ID();
END//



DROP FUNCTION IF EXISTS UseRecoveryToken//
CREATE FUNCTION `UseRecoveryToken`	( 	`Token` VARCHAR(100) charset utf8
									)	RETURNS int(11)
    NO SQL
BEGIN
	DECLARE checker INT;

	SET checker = -1;
	SELECT recovery_tokens.ID
	INTO checker
	FROM `recovery_tokens`
	WHERE recovery_tokens.Token = Token
	LIMIT 1;
	IF checker <= 0 THEN
		RETURN -1;
	END IF; 

	UPDATE `recovery_tokens`
	SET recovery_tokens.isUsed = 1
	WHERE recovery_tokens.Token = Token
	LIMIT 1;
END//



DROP PROCEDURE IF EXISTS GetRecoveryInfoByToken//
CREATE PROCEDURE `GetRecoveryInfoByToken`	( 	IN `Token` VARCHAR(100) charset utf8
											)
    NO SQL
BEGIN 
	SELECT 	recovery_tokens.ID,
			recovery_tokens.AccountID,
			recovery_tokens.Date,
			recovery_tokens.Token,
			recovery_tokens.isUsed
	FROM `recovery_tokens`
	WHERE recovery_tokens.Token = Token
	LIMIT 1;
END //


DELIMITER ;